summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp2.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/menuapp2.py')
-rw-r--r--templates/annotated/menuapp2.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/templates/annotated/menuapp2.py b/templates/annotated/menuapp2.py
index 6447d1c..8d79dd1 100644
--- a/templates/annotated/menuapp2.py
+++ b/templates/annotated/menuapp2.py
@@ -44,15 +44,15 @@ import sys
from qt import TQPopupMenu, SIGNAL
from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData, i18n
-from tdeui import KMainWindow, KMessageBox, KStdAction, KAction
+from tdeui import TDEMainWindow, KMessageBox, KStdAction, TDEAction
STATUSBAR_LEFT = 1
STATUSBAR_MIDDLE = 2
STATUSBAR_RIGHT = 3
-class MainWin (KMainWindow):
+class MainWin (TDEMainWindow):
def __init__ (self, *args):
- apply (KMainWindow.__init__, (self,) + args)
+ apply (TDEMainWindow.__init__, (self,) + args)
# Create the actions that will populate
# the menus and toolbars
@@ -106,16 +106,16 @@ class MainWin (KMainWindow):
self.replaceAction = KStdAction.replace (self.slotReplace)
# For actions that are not "standard", you can create your
# own actions using KAction. This example doesn't include
# an icon, but there is a KAction constructor that will
# allow you to specify an icon (for toolbar use, for instance),
# or you can use KAction.setIcon to set/change the icon. You
# can also add a tooltip with KAction.setToolTip
# This KAction constructor requires a TQString, an accelerator (0
# in this case), a slot, and a TQObject (None in this case)
- self.specialAction = KAction (i18n ("Special"), 0, self.slotSpecial, None)
+ self.specialAction = TDEAction (i18n ("Special"), 0, self.slotSpecial, None)
def initMenus (self):
# plug the actions into the menus
@@ -106,16 +106,16 @@ class MainWin (KMainWindow):
self.replaceAction = KStdAction.replace (self.slotReplace)
# For actions that are not "standard", you can create your
- # own actions using KAction. This example doesn't include
- # an icon, but there is a KAction constructor that will
+ # own actions using TDEAction. This example doesn't include
+ # an icon, but there is a TDEAction constructor that will
# allow you to specify an icon (for toolbar use, for instance),
@@ -106,16 +106,16 @@ class MainWin (KMainWindow):
# allow you to specify an icon (for toolbar use, for instance),
- # or you can use KAction.setIcon to set/change the icon. You
- # can also add a tooltip with KAction.setToolTip
+ # or you can use TDEAction.setIcon to set/change the icon. You
+ # can also add a tooltip with TDEAction.setToolTip
- # This KAction constructor requires a TQString, an accelerator (0
+ # This TDEAction constructor requires a TQString, an accelerator (0
# in this case), a slot, and a TQObject (None in this case)